<!-- Header -->
<div id="top" align="center">
  <br />
  
  <!-- Logo -->
  <img src="public/favicon.svg" alt="Logo" width="200" height="200">

  <!-- Title -->
  ### Momentum
  
  <!-- Description -->
  Server Development Platform

  <!-- Repo badges -->
  [![Version](https://img.shields.io/badge/dynamic/json.svg?label=Version&style=for-the-badge&url=https://git.zakscode.com/api/v1/repos/ztimson/momentum/tags%3Ftoken%3D35a3bf73a216782a7435f86117412bcb9784b716&query=$[0].name)](https://git.zakscode.com/ztimson/momentum/tags)
  [![Pull Requests](https://img.shields.io/badge/dynamic/json.svg?label=Pull%20Requests&style=for-the-badge&url=https://git.zakscode.com/api/v1/repos/ztimson/momentum%3Ftoken%3D35a3bf73a216782a7435f86117412bcb9784b716&query=open_pr_counter)](https://git.zakscode.com/ztimson/momentum/pulls)
  [![Issues](https://img.shields.io/badge/dynamic/json.svg?label=Issues&style=for-the-badge&url=https://git.zakscode.com/api/v1/repos/ztimson/momentum%3Ftoken%3D35a3bf73a216782a7435f86117412bcb9784b716&query=open_issues_count)](https://git.zakscode.com/ztimson/momentum/issues)

  <!-- Links -->

  ---
  <div>
    <a href="https://git.zakscode.com/ztimson/momentum/wiki" target="_blank">Documentation</a>
    • <a href="https://git.zakscode.com/ztimson/momentum/releases" target="_blank">Release Notes</a>
    • <a href="https://git.zakscode.com/ztimson/momentum/issues/new?template=.github%2fissue_template%2fbug.md" target="_blank">Report a Bug</a>
    • <a href="https://git.zakscode.com/ztimson/momentum/issues/new?template=.github%2fissue_template%2fenhancement.md" target="_blank">Request a Feature</a>
  </div>

  ---
</div>

## Table of Contents
- [Momentum](#top)
  - [About](#about)
    - [Built With](#built-with)
  - [Setup](#setup)
    - [Production](#production)
    - [Development](#development)
  - [License](#license)

## About

Momentum is a self-hosted server development platform. What does that mean? Think something similar to [Firebase](https://firebase.google.com) but you are in full control of your data & services.

It was developed as a generic server backend for single page applications such as angular, react, svelte or vue. This enables rapid development of the client front-end application or website.

Features include:
  - WIP: Admin Panel
    - Use the web UI to manage server features while you build your front end
    - White labeled so it can use it as a content management system
    - View the source code for real examples of how to use the server API
  - [Client Library](https://git.zakscode.com/ztimson/momentum/wiki/Client)
    - TypeScript, ESM & UMD compatible client library for native JavaScript environments
  - Authentication
    - Manage users & save user data 
    - Custom password strength rules
    - Account validation & reset emails
    - User groups
    - Permissions for all modules
    - Custom permissions
    - Optionally allow public registration
  - Data
    - Generic collection/do`cument database accessible via REST
    - Granular collection & document level permissions
    - Metadata such as created & modified by is tracked
    - Uses MongoDB
  - Email
    - Supports SMTP
    - HTML email templates
    - Send emails using post requests
    - WIP: Handle newsletter subscriptions
    - WIP: Send newsletters via post request
  - [File Storage](https://git.zakscode.com/ztimson/momentum/wiki/Storage)
    - Upload files using file input field
    - Navigate storage via API
    - Automatically track metadata
    - Granular, file level, permissions
  - [Static File Server](https://git.zakscode.com/ztimson/momentum/wiki/Static)
    - Host your single page application using Momentum for easy hosting
    - Volumize or extend the momentum docker image to include your static website in `/app/public`
    - Enable the single page application redirects with the environment variable: `NOT_FOUND_REDIRECT=TRUE`
  - [Variables](https://git.zakscode.com/ztimson/momentum/wiki/Variables)
    - Manage the server through variables which can be changed at runtime
    - Create & use custom variables for your application
    - Granular, variable level, permissions

### Built With
[![Docker](https://img.shields.io/badge/Docker-384d54?style=for-the-badge&logo=docker)](https://docker.com/)
[![MongoDB](https://img.shields.io/badge/mongodb-000000?style=for-the-badge&logo=mongodb)](https://www.mongodb.com/)
[![Node](https://img.shields.io/badge/Node.js-000000?style=for-the-badge&logo=nodedotjs)](https://nodejs.org/)
[![TypeScript](https://img.shields.io/badge/TypeScript-3178C6?style=for-the-badge&logo=typescript&logoColor=white)](https://typescriptlang.org/)

## Setup

<details>
	<summary>
		<h3 id="production" style="display: inline">Production</h3>
	</summary>

#### Prerequisites
- [Docker](https://docs.docker.com/install/)

#### Instructions
1. _Optional: Use momentum to host your [static site](https://git.zakscode.com/ztimson/momentum/wiki/Static)_
2. Download the [docker-compose](https://git.zakscode.com/ztimson/momentum/src/branch/develop/docker-compose.yml) file: `curl -o momentum.yaml https://git.zakscode.com/ztimson/momentum/raw/branch/develop/docker-compose.yml`
3. Configure the [Environment Variables](https://git.zakscode.com/ztimson/momentum/wiki/Environment-Variables) inside the docker-compose
4. Start the server with: `docker-compose up -f momentum.yaml`
5. Open http://localhost:80
	- Default login: `admin/admin`
	- Configure [System Variables](https://git.zakscode.com/ztimson/momentum/wiki/System-Variables)

</details>

<details>
	<summary>
	  <h3 id="development" style="display: inline">Development</h3>
	</summary>

#### Prerequisites
- [Node.js](https://nodejs.org/en/download)

#### Instructions
1. Install the dependencies: `npm install`
2. Start MongoDB: `docker-compose up db`
3. Start the dev server: `npm run start`
4. Open http://localhost:3000
	- Default login: `admin/admin`
	- Configure [System Variables](https://git.zakscode.com/ztimson/momentum/wiki/System-Variables)

</details>

## License
Copyright © 2023 Zakary Timson | Available under MIT Licensing

See the [license](./LICENSE) for more information.
