import { Meta } from './core';
import { BehaviorSubject } from 'rxjs';
import { TypedEmitter, XhrOptions, TypedEvents } from '@ztimson/utils';
import { Api } from './api';

export type Action = Meta & {
    name: string;
    trigger: {
        type: ActionType;
        value: string;
    };
    system: boolean;
    fn: string;
    notes: string;
    lastRun: number;
};
export type ActionResponse = {
    action: string;
    stdout: any[];
    stderr: any[];
    return?: any;
};
export declare enum ActionType {
    'DISABLED' = 0,
    'CRON' = 1,
    'EVENT' = 2,
    'GET' = 3,
    'POST' = 4,
    'PATCH' = 5,
    'PUT' = 6,
    'DELETE' = 7
}
export type ActionEvents = TypedEvents & {
    LIST: (actions: Action[]) => any;
    DELETE: (id: string) => any;
    READ: (action: Action | null) => any;
    UPDATE: (action: Action) => any;
    EXECUTE: (action: Action, resp: any) => any;
};
export declare class Actions extends TypedEmitter<ActionEvents> {
    private readonly api;
    $cache: BehaviorSubject<Action[]>;
    get cache(): Action[];
    set cache(val: Action[]);
    constructor(api: Api | string);
    delete(id: string): Promise<void>;
    list(): Promise<Action[]>;
    read(id: string, reload?: boolean): Promise<Action | null>;
    run<T>(path: string, opts?: XhrOptions): Promise<T>;
    runById(action: string | Action, opts?: XhrOptions): Promise<ActionResponse>;
    update(action: Action): Promise<Action>;
}
//# sourceMappingURL=actions.d.ts.map