import { LOG_LEVEL } from '@ztimson/utils';
import { Api } from './api';

export type LogLevel = 'ERROR' | 'WARN' | 'INFO' | 'LOG' | 'DEBUG' | 'NONE';
export type Log<T> = {
    time: number;
    level: LOG_LEVEL;
    log: any[];
    ctx?: T;
};
export type ClientLog = Log<{
    url: string;
    user: string;
    ip: string;
    res: [number, number];
    ua: string | {
        ua: string;
        browser: {
            name: string;
            version: string;
            major: string;
        };
        cpu: {
            architecture: string;
        };
        device: {
            mode?: string;
            type?: string;
        };
        engine: {
            name: string;
            version: string;
        };
        os: {
            name: string;
            version: string;
        };
    };
}>;
export declare class Logger {
    private readonly api;
    constructor(api: Api | string, logLevel?: LogLevel | null);
    private buildLog;
    clearClientLogs(): Promise<ClientLog[]>;
    clearServerLogs(): Promise<ClientLog[]>;
    clientLogs(length?: number, page?: number): Promise<ClientLog[]>;
    serverLogs(length?: number, page?: number): Promise<Log<any>[]>;
    debug(...logs: any[]): Promise<unknown>;
    log(...logs: any[]): Promise<unknown>;
    info(...logs: any[]): Promise<unknown>;
    warn(...logs: any[]): Promise<unknown>;
    error(...logs: any[]): Promise<unknown>;
}
//# sourceMappingURL=logger.d.ts.map